@@ -176,6 +176,7 @@ class Station(BaseStation):
             humidity=conditions.humidity * 100.0,
             dew_point=conditions.dewPoint,
             abs_pressure=units.hPa(conditions.pressure).inHg,
+            precip_hour=units.mmph(conditions.precipIntensity).inph,
             cloud_cover=conditions.cloudCover * 100.0,
             visibility=conditions.visibility,
             uv_index=conditions.uvIndex,
@@ -205,7 +206,7 @@ class Station(BaseStation):
                 wind_gusts=hour.windGust,
                 wind_bearing=hour.windBearing,
                 humidity=hour.humidity,
-                precip=hour.precipIntensity,
+                precip=units.mmph(hour.precipIntensity).inph,
                 abs_pressure=units.hPa(hour.pressure).inHg,
                 cloud_cover=hour.cloudCover * 100.0,
                 visibility=hour.visibility,
